@@ -6,6 +6,7 @@
 
 import os
 import subprocess
+import locale
 
 class ImConfig(object):
     
@@ -30,18 +31,29 @@ class ImConfig(object):
         let's ask the system and save the system configuration as the user ditto
         """
         system_conf = ''
+        try:
+            locale.setlocale(locale.LC_ALL, '')
+        except locale.Error:
+            return None
+        else:
+            loc = locale.getlocale(locale.LC_CTYPE)[0]
+        if os.environ.get('XDG_CURRENT_DESKTOP') == 'Unity' \
+          or loc.startswith('zh_') \
+          or loc.startswith('ja_') \
+          or loc.startswith('ko_') \
+          or loc.startswith('vi_'):
+            system_default = autoConfig
+        else:
+            system_default = 'xim'
         if systemConfig == 'default':
-            # Using the autoConfig value might be incorrect if the mode in
-            # /etc/default/im-config is 'cjkv'. However, as from im-config 0.24-1ubuntu1
-            # the mode is 'auto' for all users of language-selector-gnome.
-            system_conf = autoConfig
+            system_conf = system_default
         elif os.path.exists('/etc/X11/xinit/xinputrc'):
             for line in open('/etc/X11/xinit/xinputrc'):
                 if line.startswith('run_im'):
                     system_conf = line.split()[1]
                     break
         if not system_conf:
-            system_conf = autoConfig
+            system_conf = system_default
         self.setInputMethod(system_conf)
         return system_conf
 
